couchdb.tools.replication_helper_test

Package couchdb :: Package tools :: Module replication_helper_test |

# Module replication_helper_test

Simple functional test for the replication notification trigger

Functions
set_up_database(server, database) Deletes and creates a `database` on a `server` |
run_tests() Inserts a doc into database a, waits and tries to read it back from database b |
main() |

Variables
| __package__ = ``'``couchdb.tools``'``